<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "%s に提供された無効な値",
"Saved" => "保存されました",
"test email settings" => "メール設定をテスト",
"If you received this email, the settings seem to be correct." => "このメールを受け取ったら、設定は正しいはずです。",
"A problem occurred while sending the e-mail. Please revisit your settings." => "メールの送信中に問題が発生しました。設定を再考してください。",
"Email sent" => "メールを送信しました",
"You need to set your user email before being able to send test emails." => "ユーザーメールを設定して初めて、テストメールを送信することができるようになります。",
"Send mode" => "送信モード",
"Encryption" => "暗号化",
"Authentication method" => "認証方法",
"Unable to load list from App Store" => "アプリストアからリストをロードできません",
"Authentication error" => "認証エラー",
"Your full name has been changed." => "名前を変更しました。",
"Unable to change full name" => "名前を変更できません",
"Group already exists" => "グループはすでに存在します",
"Unable to add group" => "グループを追加できません",
"Files decrypted successfully" => "ファイルの復号化に成功しました",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "ファイルを復号化することができませんでした。owncloud のログを調査するか、管理者に連絡してください。",
"Couldn't decrypt your files, check your password and try again" => "ファイルを復号化することができませんでした。パスワードを確認のうえ再試行してください。",
"Encryption keys deleted permanently" => "暗号化キーは完全に削除されます",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "暗号化キーを完全に削除できませんでした。owncloud.logを確認するか、管理者に問い合わせてください。",
"Couldn't remove app." => "アプリが削除できませんでした。",
"Email saved" => "メールアドレスを保存しました",
"Invalid email" => "無効なメールアドレス",
"Unable to delete group" => "グループを削除できません",
"Unable to delete user" => "ユーザーを削除できません",
"Backups restored successfully" => "バックアップの復元に成功しました",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "暗号化キーを復元できませんでした。owncloud.logを確認するか、管理者に問い合わせてください。",
"Language changed" => "言語が変更されました",
"Invalid request" => "不正なリクエスト",
"Admins can't remove themself from the admin group" => "管理者は自身を管理者グループから削除できません。",
"Unable to add user to group %s" => "ユーザーをグループ %s に追加できません",
"Unable to remove user from group %s" => "ユーザーをグループ %s から削除できません",
"Couldn't update app." => "アプリをアップデートできませんでした。",
"Wrong password" => "無効なパスワード",
"No user supplied" => "ユーザーが指定されていません",
"Please provide an admin recovery password, otherwise all user data will be lost" => "リカバリ用の管理者パスワードを入力してください。そうでない場合は、全ユーザーのデータが失われます。",
"Wrong admin recovery password. Please check the password and try again." => "リカバリ用の管理者パスワードが間違っています。パスワードを確認して再度実行してください。",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "バックエンドはパスワード変更をサポートしていませんが、ユーザーの暗号化キーは正常に更新されました。",
"Unable to change password" => "パスワードを変更できません",
"Sending..." => "送信中…",
"User Documentation" => "ユーザードキュメント",
"Admin Documentation" => "管理者ドキュメント",
"Update to {appversion}" => "{appversion} にアップデート",
"Uninstall App" => "アプリをアンインストール",
"Disable" => "無効",
"Enable" => "有効にする",
"Please wait...." => "しばらくお待ちください。",
"Error while disabling app" => "アプリ無効化中にエラーが発生",
"Error while enabling app" => "アプリを有効にする際にエラーが発生",
"Updating...." => "更新中....",
"Error while updating app" => "アプリの更新中にエラーが発生",
"Error" => "エラー",
"Update" => "アップデート",
"Updated" => "アップデート済み",
"Uninstalling ...." => "アンインストール中 ....",
"Error while uninstalling app" => "アプリをアンインストール中にエラーが発生",
"Uninstall" => "アンインストール",
"Select a profile picture" => "プロファイル画像を選択",
"Very weak password" => "非常に弱いパスワード",
"Weak password" => "弱いパスワード",
"So-so password" => "まずまずのパスワード",
"Good password" => "良好なパスワード",
"Strong password" => "強いパスワード",
"Decrypting files... Please wait, this can take some time." => "ファイルを複合中... しばらくお待ちください、この処理には少し時間がかかるかもしれません。",
"Delete encryption keys permanently." => "暗号化キーを永久に削除する。",
"Restore encryption keys." => "暗号化キーを復元する。",
"Unable to delete {objName}" => "{objName} を削除できません",
"Error creating group" => "グループの作成エラー",
"A valid group name must be provided" => "有効なグループ名を指定する必要があります",
"deleted {groupName}" => "{groupName} を削除しました",
"undo" => "元に戻す",
"Groups" => "グループ",
"Group Admin" => "グループ管理者",
"Delete" => "削除",
"never" => "無し",
"deleted {userName}" => "{userName} を削除しました",
"add group" => "グループを追加",
"A valid username must be provided" => "有効なユーザー名を指定する必要があります",
"Error creating user" => "ユーザー作成エラー",
"A valid password must be provided" => "有効なパスワードを指定する必要があります",
"Warning: Home directory for user \"{user}\" already exists" => "警告: ユーザー \"{user}\" のホームディレクトリはすでに存在します",
"__language_name__" => "Japanese (日本語)",
"Everything (fatal issues, errors, warnings, info, debug)" => "すべて (致命的な問題、エラー、警告、情報、デバッグ)",
"Info, warnings, errors and fatal issues" => "情報、警告、エラー、致命的な問題",
"Warnings, errors and fatal issues" => "警告、エラー、致命的な問題",
"Errors and fatal issues" => "エラー、致命的な問題",
"Fatal issues only" => "致命的な問題のみ",
"None" => "なし",
"Login" => "ログイン",
"Plain" => "平文",
"NT LAN Manager" => "NT LAN マネージャー",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "セキュリティ警告",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "HTTP経由で %s にアクセスしています。HTTPSを使用するようサーバーを設定することを強くおすすめします。",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "データディレクトリとファイルがインターネットからアクセス可能になっている可能性があります。.htaccessファイルが機能していません。データディレクトリがアクセスされないようにウェブサーバーを設定するか、ウェブサーバーのドキュメントルートからデータディレクトリを移動するように強くお勧めします。",
"Setup Warning" => "セットアップ警告",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "WebDAVインターフェースに問題があると思われるため、WEBサーバーはまだファイルの同期を許可するよう適切に設定されていません。",
"Please double check the <a href=\"%s\">installation guides</a>." => "<a href=\"%s\">installation guides</a>をもう一度チェックするようにお願いいたします。",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレータが原因かもしれません。",
"Database Performance Info" => "データベースパフォーマンス情報",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "SQLite をデータベースとして利用します。大規模な運用では、利用しないことをお勧めします。別のデータベースへ移行する場合は、コマンドラインツール: 'occ db:convert-type'を使ってください。",
"Module 'fileinfo' missing" => "モジュール 'fileinfo' が見つかりません",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP のモジュール 'fileinfo' が見つかりません。mimeタイプの検出を精度良く行うために、このモジュールを有効にすることを強くお勧めします。",
"Your PHP version is outdated" => "PHPバーションが古くなっています。",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "PHPバーションが古くなっています。古いバージョンには既知の問題があるため、5.3.8以降のバージョンにアップデートすることを強く推奨します。このインストール状態では正常に動作しない可能性があります。",
"Locale not working" => "ロケールが動作していません",
"System locale can not be set to a one which supports UTF-8." => "システムロケールを UTF-8 をサポートするロケールに設定できません。",
"This means that there might be problems with certain characters in file names." => "これは、ファイル名の特定の文字に問題があることを意味しています。",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "次のロケールをサポートするために、システムに必要なパッケージをインストールすることを強くおすすめします: %s。",
"Internet connection not working" => "インターネット接続が動作していません",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "このサーバーはインターネットに接続していません。この場合、外部ストレージのマウント、更新の通知やサードパーティアプリといったいくつかの機能が使えません。また、リモート接続でのファイルアクセス、通知メールの送信と言った機能も利用できないかもしれません。全ての機能を利用したいのであれば、このサーバーからインターネットに接続できるようにすることをお勧めします。",
"Cron" => "Cron",
"Last cron was executed at %s." => "直近では %s に cron が実行されました。",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "直近では %s に cron が実行されました。これは今から１時間以上前なので、なんらかの問題が発生しているようです。",
"Cron was not executed yet!" => "cron は未だ実行されていません！",
"Execute one task with each page loaded" => "各ページの読み込み時にタスクを実行する",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.phpは、HTTP経由で15分ごとにcron.phpを実行するようwebcronサービスに登録されています",
"Use system's cron service to call the cron.php file every 15 minutes." => "システムのcronサービスを利用して15分ごとにcron.phpファイルを実行します。",
"Sharing" => "共有",
"Allow apps to use the Share API" => "アプリからの共有APIの利用を許可する",
"Allow users to share via link" => "URLリンクで共有を許可する",
"Enforce password protection" => "常にパスワード保護を有効にする",
"Allow public uploads" => "パブリックなアップロードを許可する",
"Set default expiration date" => "有効期限の既定値を設定",
"Expire after " => "無効になるまで",
"days" => "日",
"Enforce expiration date" => "有効期限を反映させる",
"Allow resharing" => "再共有を許可する",
"Restrict users to only share with users in their groups" => "グループ内のユーザーでのみ共有するように制限する",
"Allow users to send mail notification for shared files" => "共有ファイルに関するメール通知の送信をユーザーに許可する",
"Exclude groups from sharing" => "共有可能なグループから除外",
"These groups will still be able to receive shares, but not to initiate them." => "このグループでは、フォルダ共有を開始することはできませんが、共有されたフォルダを参照することはできます。",
"Security" => "セキュリティ",
"Enforce HTTPS" => "常にHTTPSを使用する",
"Forces the clients to connect to %s via an encrypted connection." => "クライアントから %sへの接続を常に暗号化します。",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "強制的なSSL接続を有効/無効にするには、HTTPS経由で %s へ接続してください。",
"Email Server" => "メールサーバー",
"This is used for sending out notifications." => "これは通知の送信に使われます。",
"From address" => "アドレスから",
"mail" => "メール",
"Authentication required" => "要求される認証",
"Server address" => "サーバーアドレス",
"Port" => "ポート",
"Credentials" => "資格情報",
"SMTP Username" => "SMTP ユーザー名",
"SMTP Password" => "SMTP パスワード",
"Test email settings" => "メール設定をテスト",
"Send email" => "メールを送信",
"Log" => "ログ",
"Log level" => "ログレベル",
"More" => "もっと見る",
"Less" => "閉じる",
"Version" => "バージョン",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "<a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud コミュニティ</a>により開発されています。 <a href=\"https://github.com/owncloud\" target=\"_blank\">ソースコード</a>は、<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> ライセンスの下で提供されています。",
"Add your App" => "アプリを追加",
"More Apps" => "さらにアプリを表示",
"Select an App" => "アプリを選択してください",
"Documentation:" => "ドキュメント:",
"See application page at apps.owncloud.com" => "apps.owncloud.com でアプリケーションのページを見てください",
"See application website" => "アプリケーションのウェブサイトを見る",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-ライセンス: <span class=\"author\"></span>",
"Enable only for specific groups" => "特定のグループのみ有効に",
"All" => "すべて",
"Administrator Documentation" => "管理者ドキュメント",
"Online Documentation" => "オンラインドキュメント",
"Forum" => "フォーラム",
"Bugtracker" => "バグトラッカー",
"Commercial Support" => "商用サポート",
"Get the apps to sync your files" => "ファイルを同期するためのアプリを取得",
"Show First Run Wizard again" => "初回ウィザードを再表示する",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "現在、<strong>%s</strong> / <strong>%s</strong> を利用しています",
"Password" => "パスワード",
"Your password was changed" => "パスワードを変更しました",
"Unable to change your password" => "パスワードを変更することができません",
"Current password" => "現在のパスワード",
"New password" => "新しいパスワード",
"Change password" => "パスワードを変更",
"Full Name" => "名前",
"Email" => "メール",
"Your email address" => "あなたのメールアドレス",
"Fill in an email address to enable password recovery and receive notifications" => "パスワードの回復を有効にし、通知を受け取るにはメールアドレスを入力してください",
"Profile picture" => "プロフィール写真",
"Upload new" => "新規にアップロード",
"Select new from Files" => "ファイルから新規に選択",
"Remove image" => "画像を削除",
"Either png or jpg. Ideally square but you will be able to crop it." => "png と jpg のいずれか。正方形が理想ですが、切り取って加工することも可能です。",
"Your avatar is provided by your original account." => "あなたのアバターは、あなたのオリジナルのアカウントで提供されています。",
"Cancel" => "キャンセル",
"Choose as profile image" => "プロファイル画像として選択",
"Language" => "言語",
"Help translate" => "翻訳に協力する",
"The encryption app is no longer enabled, please decrypt all your files" => "暗号化アプリはもはや有効ではありません、すべてのファイルを複合してください",
"Log-in password" => "ログインパスワード",
"Decrypt all Files" => "すべてのファイルを複合する",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "暗号化キーはバックアップ場所に移動されました。何か問題があった場合は、キーを復元することができます。すべてのファイルが正しく復号化されたことが確信できる場合にのみ、キーを完全に削除してください。",
"Restore Encryption Keys" => "暗号化キーを復元する",
"Delete Encryption Keys" => "暗号化キーを削除する",
"Login Name" => "ログイン名",
"Create" => "作成",
"Admin Recovery Password" => "管理者リカバリパスワード",
"Enter the recovery password in order to recover the users files during password change" => "パスワード変更時のユーザーのファイルを回復するため、リカバリパスワードを入力してください",
"Search Users and Groups" => "ユーザーとグループを検索",
"Add Group" => "グループを追加",
"Group" => "グループ",
"Everyone" => "すべてのユーザー",
"Admins" => "管理者",
"Default Quota" => "デフォルトのクォータサイズ",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "ストレージのクォータを入力してください (例: \"512MB\" や \"12 GB\")",
"Unlimited" => "無制限",
"Other" => "その他",
"Username" => "ユーザーID",
"Quota" => "クオータ",
"Storage Location" => "データの保存場所",
"Last Login" => "最終ログイン",
"change full name" => "名前を変更",
"set new password" => "新しいパスワードを設定",
"Default" => "デフォルト",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "もし、URLがドメインのルート(/)で終わっていない場合で、システムのcronを利用している場合、URLの生成に問題が発生します。その場合は、config.php ファイルの中の \"overwritewebroot\" オプションをインストールしたパスに設定してください。(推奨: \"%s\")",
"URL generation in notification emails" => "通知メールにURLを生成",
"Connectivity Checks" => "接続の確認",
"No problems found" => "問題は見つかりませんでした",
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
